% Initialize
close all;
clear;
clc;

% Inputs
FData = 'MC_inputs.mat';
FKPI = 'kpi_report.csv';
NBins = 10;
NOut = 3
NSims = 2000;
OutNames = {'Fc'; 'Bandwidth'; 'Kt2'};

% Read data
KPI = csvread(FKPI,1);
load(FData);

% Plot distributions: Input vs Input
figure;
for I = 1 : 2
    for J = 1 : 2
        P = sub2ind([2 2],I,J);
        subplot(2,2,P);
        if (I == J)
            hist(FKPI(:,I)*1e3,NBins);
        else
            scatter(FKPI(:,I)*1e3,FKPI(:,J)*1e3);
        end
        
        if (I == 1)
            ylabel({J},'FontWeight','bold');
        end
        if (J == MCData.Nv)
            xlabel(FKPI{I},'FontWeight','bold');
        end
    end
end

% Plot distributions: Input vs Ouptut
figure;
for I = 1 : MCData.Nv
    for J = 1 : NOut
        P = sub2ind([NOut MCData.Nv ],J,I);
        subplot(MCData.Nv,NOut,P);

        scatter(KPI(:,J+1),MCData.Dist(:,I)*1e3);
        
        if (J == 1)
            ylabel(MCData.VNames{I},'FontWeight','bold');
        end
        if (I == MCData.Nv)
            xlabel(OutNames{J},'FontWeight','bold');
        end
    end
end

% Plot distributions: Output vs Output
figure;
for I = 1 : NOut
    for J = 1 : NOut
        P = sub2ind([NOut NOut],I,J);
        subplot(NOut,NOut,P);
        if (I == J)
            hist(KPI(:,I+1),NBins);
        else
            scatter(KPI(:,I+1),KPI(:,J+1));
        end
        
        if (I == 1)
            ylabel(OutNames{J},'FontWeight','bold');
        end
        if (J == NOut)
            xlabel(OutNames{I},'FontWeight','bold');
        end
    end
end

% Plot Pass/Fail Criteria

% Center Frequency Pass Criteria
Fc_mean = 18e3;
Fc_sd = 0.025;

% Displacement Pass Criteria
Disp_mean = 1.19e-9;
Disp_sd = 0.05;

% Fractional Bandwidth Pass Criteria
FBW_mean = 35;
FBW_sd = 0.02;

Fc_upper = Fc_mean +(Fc_mean * Fc_sd);
Fc_lower = Fc_mean - (Fc_mean * Fc_sd);

Disp_upper = Disp_mean + (Disp_mean * Disp_sd);
Disp_lower = Disp_mean - (Disp_mean * Disp_sd);

FBW_upper = FBW_mean +(FBW_mean * FBW_sd);
FBW_lower = FBW_mean - (FBW_mean * FBW_sd);

figure;
for I = 1 : NOut
    for J = 1 : NOut
        P = sub2ind([NOut NOut],I,J);
        subplot(NOut,NOut,P);
        if (I == J)
            if (I == 1)
            hist(KPI(:,I+1),NBins);
             hold on;
            line([Fc_upper, Fc_upper], ylim, 'LineWidth', 2, 'Color', 'r');
             hold on;
            line([Fc_lower, Fc_lower], ylim, 'LineWidth', 2, 'Color', 'r');
            end
            if (I == 2)
            hist(KPI(:,I+1),NBins);
            hold on;
            line([Disp_upper, Disp_upper], ylim, 'LineWidth', 2, 'Color', 'r');
             hold on;
            line([Disp_lower, Disp_lower], ylim, 'LineWidth', 2, 'Color', 'r');
            end
            if (I == 3)
            hist(KPI(:,I+1),NBins);
            hold on;
            line([FBW_upper, FBW_upper], ylim, 'LineWidth', 2, 'Color', 'r');
             hold on;
            line([FBW_lower, FBW_lower], ylim, 'LineWidth', 2, 'Color', 'r');
            end
        else
            scatter(KPI(:,I+1),KPI(:,J+1));
        end
        
        if (I == 1)
            ylabel(OutNames{J},'FontWeight','bold');
        end
        if (J == NOut)
            xlabel(OutNames{I},'FontWeight','bold');
        end
    end
end

% Plot Final Simulation Yield

% Remove designs which do not pass Fc criteria
for i=1:length(KPI)
    if (KPI(i,2) > Fc_lower && KPI(i,2) < Fc_upper)
        KPI1(i,1) = KPI(i,1);
        KPI1(i,2) = KPI(i,2);
        KPI1(i,3) = KPI(i,3);
        KPI1(i,4) = KPI(i,4);
    end
    if ( i >= length(KPI) )
        break
    end
end
KPIFc = KPI1(any(KPI1,2),:);

% Remove designs which do not pass Disp criteria
for i=1:length(KPIFc)
    if (KPIFc(i,3) > Disp_lower && KPIFc(i,3) < Disp_upper)
        KPI2(i,1) = KPIFc(i,1);
        KPI2(i,2) = KPIFc(i,2);
        KPI2(i,3) = KPIFc(i,3);
        KPI2(i,4) = KPIFc(i,4);
    end
    if ( i >= length(KPIFc) )
        break
    end
end
KPIDisp = KPI2(any(KPI2,2),:);

% Remove designs which do not pass FBW criteria
for i=1:length(KPI)
    if (KPIDisp(i,4) > FBW_lower && KPIDisp(i,4) < FBW_upper)
        KPI3(i,1) = KPIDisp(i,1);
        KPI3(i,2) = KPIDisp(i,2);
        KPI3(i,3) = KPIDisp(i,3);
        KPI3(i,4) = KPIDisp(i,4);
    end
    if (i >= length(KPIDisp))  
        break
    end
end
KPIFin = KPI3(any(KPI3,2),:);

figure;
for I = 1 : NOut
    for J = 1 : NOut
        P = sub2ind([NOut NOut],I,J);
        subplot(NOut,NOut,P);
        if (I == J)
            hist(KPIFin(:,I+1),NBins);
        else
            scatter(KPIFin(:,I+1),KPIFin(:,J+1));
        end
        
        if (I == 1)
            ylabel(OutNames{J},'FontWeight','bold');
        end
        if (J == NOut)
            xlabel(OutNames{I},'FontWeight','bold');
        end
    end
end
