% Initialize
close all;
clear;
clc;

% Inputs
FIn = 'inputs.xlsx';
FOut = 'simdata.csv';
NSims = 2000;
NBins = 10;

% Read data
[~,~,Inputs] = xlsread(FIn,1);

% Get number of variables and preallocate
MCData.Nv = size(Inputs,1) - 1;
MCData.VNames = cell(MCData.Nv,1);
MCData.SNames = cell(MCData.Nv,1);
MCData.Mu = zeros(MCData.Nv,1);
MCData.Sig = zeros(MCData.Nv,1);
MCData.Dist = zeros(NSims,MCData.Nv);
MCData.NSims = NSims;

% Extract data for each variable and create distributions
for Index = 1 : MCData.Nv
   
    % Get params
    MCData.Mu(Index) = Inputs{Index+1,2};
    MCData.Sig(Index) = Inputs{Index+1,3};
    MCData.VNames{Index} = Inputs{Index+1,1};
    MCData.SNames{Index} = Inputs{Index+1,4};

    % Get normal MCData.Distributions
    MCData.Dist(:,Index) = MCData.Sig(Index) * randn(NSims,1) + MCData.Mu(Index);
    
end

% Plot distributions
figure;
for I = 1 : MCData.Nv
    for J = 1 : MCData.Nv
        P = sub2ind([MCData.Nv MCData.Nv],I,J);
        subplot(MCData.Nv,MCData.Nv,P);
        if (I == J)
            hist(MCData.Dist(:,I)*1e3,NBins);
        else
            scatter(MCData.Dist(:,I)*1e3,MCData.Dist(:,J)*1e3);
        end
        
        if (I == 1)
            ylabel(MCData.VNames{J},'FontWeight','bold');
        end
        if (J == MCData.Nv)
            xlabel(MCData.VNames{I},'FontWeight','bold');
        end
    end
end

% Write variable table
Fid = fopen(FOut, 'w');
fprintf(Fid,'%s,', MCData.SNames{1:end-1});
fprintf(Fid,'%s\n',MCData.SNames{end});
fclose(Fid);
dlmwrite(FOut,MCData.Dist,'-append');

% Save variables
save('MC_inputs','MCData');